@@ -15,7 +15,7 @@ namespace ze_lib
     ///////////////////////////////////////////////////////////////////////////////
 
 #ifdef DYNAMIC_LOAD_LOADER
-    __zedlllocal ze_result_t context_t::zelTracingInit()
+    __zedlllocal ze_result_t context_t::zelTracingDdiTableInit()
     {
         ze_result_t result = ZE_RESULT_SUCCESS;
 
@@ -29,7 +29,7 @@ namespace ze_lib
         return result;
     }
 #else
-    __zedlllocal ze_result_t context_t::zelTracingInit()
+    __zedlllocal ze_result_t context_t::zelTracingDdiTableInit()
     {
         ze_result_t result;
         result = zelGetTracerApiProcAddrTable( ZE_API_VERSION_CURRENT, &zelTracingDdiTable.Tracer);
